function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { useThemeProps } from '../../../hooks';
import { useToken } from '../../../hooks';
import styled from 'styled-components/native';
import { border, color, flexbox, layout, space, typography, position } from 'styled-system';
import { customBorder, customBackground, customOutline, customLayout, customExtra, customShadow, customTypography, customPosition } from '../../../utils/customProps';
import { Svg, Path, G, Circle, Ellipse, Text, TSpan, TextPath, Polygon, Polyline, Line, Rect, Use, Image, Symbol, Defs, LinearGradient, RadialGradient, Stop, ClipPath, Pattern, Mask } from 'react-native-svg';
const VALID_SVG_COMPONENTS = {
  G,
  Path,
  Circle,
  Ellipse,
  Text,
  TSpan,
  TextPath,
  Polygon,
  Polyline,
  Line,
  Rect,
  Use,
  Image,
  Symbol,
  Defs,
  LinearGradient,
  RadialGradient,
  Stop,
  ClipPath,
  Pattern,
  Mask
};
const SVG = styled(Svg)(color, space, layout, flexbox, border, typography, position, customPosition, customBorder, customBackground, customOutline, customShadow, customExtra, customLayout, customTypography);

const SVGIcon = ({
  viewBox,
  color: colorProp,
  stroke,
  strokeWidth,
  children,
  focusable,
  size,
  style
}, ref) => {
  const newProps = useThemeProps('Icon', {
    size
  });
  let strokeColor = useToken('colors', stroke || '');
  colorProp = useToken('colors', colorProp || '');
  return /*#__PURE__*/React.createElement(SVG, {
    height: newProps.size ? parseInt(newProps.size, 10) : parseInt(newProps.height, 10),
    width: newProps.size ? parseInt(newProps.size, 10) : parseInt(newProps.width, 10),
    viewBox: viewBox,
    color: colorProp,
    stroke: strokeColor,
    strokeWidth: strokeWidth,
    focusable: focusable,
    accessibilityRole: 'image',
    style: style,
    ref: ref
  }, React.Children.count(children) > 0 ? /*#__PURE__*/React.createElement(G, null, React.Children.map(children, ({
    props: childProps,
    type
  }) => type && type.name && Object.keys(VALID_SVG_COMPONENTS).includes(type.name) ? /*#__PURE__*/React.createElement(ChildPath, _extends({}, childProps, {
    type: type.name
  })) : null)) : getDefaultIcon(ref));
};

const ChildPath = ({
  type,
  fill,
  stroke: pathStroke,
  ...remainingProps
}) => {
  const Component = VALID_SVG_COMPONENTS[type];
  const pathStrokeColor = useToken('colors', pathStroke || '');
  const fillColor = useToken('colors', fill || '');

  if (!Component) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Component, _extends({}, remainingProps, {
    fill: fillColor ? fillColor : 'currentColor',
    stroke: pathStrokeColor
  }));
};

const getDefaultIcon = ref => {
  return /*#__PURE__*/React.createElement(G, {
    strokeWidth: 1.5,
    stroke: "currentColor",
    ref: ref
  }, /*#__PURE__*/React.createElement(Path, {
    d: 'M9,9a3,3,0,1,1,4,2.829,1.5,1.5,0,0,0-1,1.415V14.25',
    fill: "none"
  }), /*#__PURE__*/React.createElement(Path, {
    d: 'M12,17.25a.375.375,0,1,0,.375.375A.375.375,0,0,0,12,17.25h0',
    fill: "none"
  }), /*#__PURE__*/React.createElement(Circle, {
    cx: "12",
    cy: "12",
    r: "11.25",
    fill: "none"
  }));
};

export default /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(SVGIcon));
//# sourceMappingURL=SVGIcon.js.map